/* Copyright 1999 by Herve Regad-Pellagru, E-mail: herve.regadpellagru@free.fr

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */

#include <stdio.h>

#include "common.h"
#include "proto.h"

extern FILE *log_file;

static char *cmd_to_string[]={
  "X10_CMD_ALL_UNITS_OFF",
  "X10_CMD_ALL_LIGHTS_ON",
  "X10_CMD_ON",
  "X10_CMD_OFF",
  "X10_CMD_DIM",
  "X10_CMD_BRIGHT",
  "X10_CMD_ALL_LIGHTS_OFF",
  "X10_CMD_EXTENDED_CODE",
  "X10_CMD_HAIL_REQUEST",
  "X10_CMD_HAIL_AKNOWLEDGE",
  "X10_CMD_PRE_SET_DIM1",
  "X10_CMD_PRE_SET_DIM2",
  "X10_CMD_EXTENDED_DATA_TRANSFER",
  "X10_CMD_STATUS_ON",
  "X10_CMD_STATUS_OFF",
  "X10_CMD_STATUS_REQUEST"
};

static char *err_to_string[]={
  "NO ERR",
  "OPEN_FAILED",
  "TCGETATTR_FAILED",
  "WRITE_FAILED",
  "READ_FAILED",
  "TRANSMIT_FAILED	",
  "MALLOC_FAILED",
  "CHECKSUM_FAILED",
  "SELECT_FAILED",
  "TIMEOUT_READ",
  "CHAT_INTERRUPTED"
};

static char *status_to_string[]={
  "X10_OBJECT_UNKNOWN",
  "X10_OBJECT_ON",
  "X10_OBJECT_OFF",
  "X10_OBJECT_DIM_BRIGHT"
};


/* our error function */
void fatal_error(char *msg)
{
  fprintf(stderr,msg);
  exit(1);
}


/* returns a string for the X10 command number */
char *cmd2string(int command)
{
  return(cmd_to_string[command]);
}

/* returns an int X10 command which correspond to the string 
   in argument */
int string2cmd(char *command)
{
  int i;

  for(i=0;i<16 && strcmp(command,cmd_to_string[i]);i++);

  return(i==16 ? -1 : i);
}

/* returns a string for the X10 status number */
char *status2string(int status)
{
  return(status_to_string[status]);
}

/* returns a string for the X10 error number */
char *err2string(int error)
{
  return(err_to_string[-error]);
}

/* we return a string describing the current time */
char *print_ltime(void)
{
  static char string[MAXBUF];
  struct tm *ltime;
  time_t abstime;

  abstime=time(NULL);
  ltime=localtime(&abstime);

  sprintf(string,"%d/%d/%d %d:%d:%d",ltime->tm_mday,ltime->tm_mon+1,
	  ltime->tm_year,ltime->tm_hour,ltime->tm_min,ltime->tm_sec);
  return(string);
}


/* we return a string describing the time of the timestamp */
char *print_ltimestamp(time_t timestanp)
{
  static char string[MAXBUF];
  struct tm *ltime;

  ltime=localtime(&timestanp);

  sprintf(string,"%d/%d/%d %d:%d:%d",ltime->tm_mday,ltime->tm_mon+1,
	  ltime->tm_year,ltime->tm_hour,ltime->tm_min,ltime->tm_sec);
  return(string);
}


/* We log a string to our server log, with the time */
void server_log_event(char *string)
{
  fprintf(log_file,"%s %s",print_ltime(),string);
}
